pub struct Artifact {
pub name: &'static str,
pub env: &'static str,
pub dir: &'static str,
pub marker: &'static str,
pub source: Source,
pub approx_mb: u32,
pub purpose: &'static str,
}Expand description
One resolvable set of weights.
Fields
name: &'static strstable name used by resolve
env: &'static strenvironment variable that overrides the search, if set
dir: &'static strdirectory name under the model root
marker: &'static stra file that must exist for the directory to count as present
source: Sourceapprox_mb: u32purpose: &'static strTrait Implementations