pub fn s_clusters(
ix: &InfonIndex<RoarPostings>,
s: usize,
k: usize,
noise: &HashSet<String>,
) -> ValueExpand description
Connected components of the structural graph at overlap threshold s — the token clusters.
pub fn s_clusters(
ix: &InfonIndex<RoarPostings>,
s: usize,
k: usize,
noise: &HashSet<String>,
) -> ValueConnected components of the structural graph at overlap threshold s — the token clusters.