type_allowed

Function type_allowed 

pub fn type_allowed(
    spec: &VocabularySpace,
    mask: &HashSet<(String, String, String)>,
    fh: &str,
    ft: &str,
    class: usize,
) -> bool
The type mask: true where relation class r is declarable for a pair of facets. Class 0 (none) is always allowed; a declared relation is allowed only for its exact head/tail facets.