pub fn evaluate<B: Postings, S: TokenStore<B>>(store: &S, expr: &str) -> BExpand description
Evaluate a query, returning empty on refusal. Kept for callers that cannot act on an error.
pub fn evaluate<B: Postings, S: TokenStore<B>>(store: &S, expr: &str) -> BEvaluate a query, returning empty on refusal. Kept for callers that cannot act on an error.