breakdown

Function breakdown 

pub fn breakdown(
    ix: &InfonIndex<RoarPostings>,
    anchor: &str,
    facet: &str,
    k: usize,
) -> Value
Partition an anchor set by the values of a facet: for each facet/value, the anchor ∩ token count. A breakdown of an explicitly requested facet shows ALL its values — the high-DF registration filter (which belongs on the structural graph) must not hide the most frequent values here.